@@ -49,6 +49,19 @@ def _approx_count_distinct_sql(self, expression):
     return f"APPROX_COUNT_DISTINCT({self.sql(expression, 'this')})"
 
 
+def _case_if_sql(self, expression):
+    if len(expression.args['ifs']) > 1:
+        return self.case_sql(expression)
+
+    args = expression.args
+
+    return _if_sql(self, exp.If(
+        condition=args['ifs'][0].args['condition'],
+        true=args['ifs'][0].args['true'],
+        false=args.get('default')
+    ))
+
+
 def _if_sql(self, expression):
     expressions = csv(
         self.sql(expression, 'condition'),
@@ -134,6 +147,7 @@ class Hive(Dialect):
         exp.ApproxDistinct: _approx_count_distinct_sql,
         exp.ArrayAgg: lambda self, e: f"COLLECT_LIST({self.sql(e, 'this')})",
         exp.ArraySize: lambda self, e: f"SIZE({self.sql(e, 'this')})",
+        exp.Case: _case_if_sql,
         exp.DateDiff: lambda self, e: f"DATEDIFF({self.sql(e, 'this')}, {self.sql(e, 'value')})",
         exp.DateStrToDate: lambda self, e: self.sql(e, 'this'),
         exp.FileFormat: _fileformat_sql,
@@ -217,6 +231,10 @@ class Presto(Dialect):
     def _date_parse_sql(self, expression):
         return f"DATE_PARSE({self.sql(expression, 'this')}, '%Y-%m-%d %H:%i:%s')"
 
+    def _initcap_sql(self, expression):
+        regex = '(\w)(\w*)'  # pylint: disable=anomalous-backslash-in-string
+        return f"REGEXP_REPLACE({self.sql(expression, 'this')}, '{regex}', x -> UPPER(x[1]) || LOWER(x[2]))"
+
     def _str_position_sql(self, expression):
         this = self.sql(expression, 'this')
         substr = self.sql(expression, 'substr')
@@ -244,11 +262,13 @@ class Presto(Dialect):
         exp.BitwiseOr: lambda self, e: f"BITWISE_OR({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.BitwiseRightShift: lambda self, e: f"BITWISE_ARITHMETIC_SHIFT_RIGHT({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.BitwiseXor: lambda self, e: f"BITWISE_XOR({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
+        exp.Case: _case_if_sql,
         exp.DateAdd: lambda self, e: f"DATE_ADD('day', {self.sql(e, 'value')}, {self.sql(e, 'this')})",
         exp.DateDiff: lambda self, e: f"DATE_DIFF('day', {self.sql(e, 'value')}, {self.sql(e, 'this')})",
         exp.DateStrToDate: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, '%Y-%m-%d')",
         exp.FileFormat: _fileformat_sql,
         exp.If: _if_sql,
+        exp.Initcap: _initcap_sql,
         exp.JSONPath: lambda self, e: f"JSON_EXTRACT({self.sql(e, 'this')}, {self.sql(e, 'path')})",
         exp.RegexLike: lambda self, e: f"REGEXP_LIKE({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.StrPosition: _str_position_sql,
