@@ -184,7 +184,13 @@ class Select(Expression):
 
 class Window(Expression):
     token_type = TokenType.OVER
-    arg_types = {'this': True, 'partition': False, 'order': False}
+    arg_types = {'this': True, 'partition': False, 'order': False, 'spec': False}
+
+
+class WindowSpec(Expression):
+    token_type = TokenType.SPEC
+    arg_types = {'kind': False, 'start': False, 'start_side': False, 'end': False, 'end_side': False}
+
 
 # Binary Expressions
 # (PLUS a b)
@@ -346,6 +352,11 @@ class In(Expression):
     arg_types = {'this': True, 'expressions': True}
 
 
+class Interval(Expression):
+    token_type = TokenType.IN
+    arg_types = {'this': True, 'unit': True}
+
+
 # Functions
 class Func(Expression):
     token_type = TokenType.FUNC
@@ -393,6 +404,10 @@ class If(Func):
     arg_types = {'condition': True, 'true': True, 'false': False}
 
 
+class Initcap(Func):
+    arg_types = {'this': True}
+
+
 class JSONPath(Func):
     arg_types = {'this': True, 'path': True}
 
