@@ -38,6 +38,7 @@ class Generator:
         exp.DateAdd: lambda self, e: f"DATE_ADD({self.sql(e, 'this')}, {self.sql(e, 'value')})",
         exp.DateDiff: lambda self, e: f"DATE_DIFF({self.sql(e, 'this')}, {self.sql(e, 'value')})",
         exp.DateStrToDate: lambda self, e: f"DATE_STR_TO_DATE({self.sql(e, 'this')})",
+        exp.Initcap: lambda self, e: f"INITCAP({self.sql(e, 'this')})",
         exp.StrPosition: lambda self, e: f"STR_POSITION({csv(self.sql(e, 'this'), self.sql(e, 'substr'), self.sql(e, 'position'))})",
         exp.StrToTime: lambda self, e: f"STR_TO_TIME({self.sql(e, 'this')}, {self.sql(e, 'format')})",
         exp.StrToUnix: lambda self, e: f"STR_TO_UNIX({self.sql(e, 'this')}, {self.sql(e, 'format')})",
@@ -246,7 +247,15 @@ class Generator:
         order = expression.args.get('order')
         order_sql = self.order_sql(order, flat=True) if order else ''
         partition_sql = partition + ' ' if partition and order else partition
-        return f"{this_sql} OVER({partition_sql}{order_sql})"
+        spec = expression.args.get('spec')
+        spec_sql = ' ' + self.window_spec_sql(spec) if spec else ''
+        return f"{this_sql} OVER({partition_sql}{order_sql}{spec_sql})"
+
+    def window_spec_sql(self, expression):
+        kind = self.sql(expression, 'kind')
+        start = csv(self.sql(expression, 'start'), self.sql(expression, 'start_side'), sep=' ')
+        end = csv(self.sql(expression, 'end'), self.sql(expression, 'end_side'), sep=' ')
+        return f"{kind} BETWEEN {start} AND {end}"
 
     def between_sql(self, expression):
         this = self.sql(expression, 'this')
@@ -286,6 +295,9 @@ class Generator:
     def in_sql(self, expression):
         return f"{self.sql(expression, 'this')} IN ({self.expressions(expression, flat=True)})"
 
+    def interval_sql(self, expression):
+        return f"INTERVAL {self.sql(expression, 'this')} {self.sql(expression, 'unit')}"
+
     def func_sql(self, expression):
         return f"{self.sql(expression, 'this').upper()}({self.expressions(expression, flat=True)})"
 
