@@ -28,6 +28,7 @@ class Parser:
         'DATE_DIFF': lambda args: exp.DateDiff(this=args[0], value=args[1]),
         'DATE_STR_TO_DATE': lambda args: exp.DateStrToDate(this=args[0]),
         'IF': lambda args: exp.If(condition=args[0], true=args[1], false=list_get(args, 2)),
+        'INITCAP': lambda args: exp.Initcap(this=args[0]),
         'STR_POSITION': lambda args: exp.StrPosition(this=args[0], substr=args[1], position=list_get(args, 2)),
         'STR_TO_TIME': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'STR_TO_UNIX': lambda args: exp.StrToUnix(this=args[0], format=args[1]),
@@ -327,14 +328,8 @@ class Parser:
         )
 
     def _parse_join(self, this):
-        side = None
-        kind = None
-
-        if self._match(TokenType.LEFT, TokenType.RIGHT, TokenType.FULL):
-            side = self._prev
-
-        if self._match(TokenType.INNER, TokenType.OUTER, TokenType.CROSS):
-            kind = self._prev
+        side = self._match(TokenType.LEFT, TokenType.RIGHT, TokenType.FULL)
+        kind = self._match(TokenType.INNER, TokenType.OUTER, TokenType.CROSS)
 
         if self._match(TokenType.JOIN):
             on = None
@@ -361,10 +356,7 @@ class Parser:
             expression = nested
         else:
             db = None
-            table = None
-
-            if self._match(TokenType.VAR, TokenType.IDENTIFIER):
-                table = self._prev
+            table = self._match(TokenType.VAR, TokenType.IDENTIFIER)
 
             if self._match(TokenType.DOT):
                 db = table
@@ -592,6 +584,11 @@ class Parser:
         if self._match(*self.PRIMARY_TOKENS):
             return self._prev
 
+        interval = self._parse_interval()
+
+        if interval:
+            return interval
+
         if self._match(TokenType.L_PAREN):
             paren = self._prev
             this = self._parse_expression()
@@ -660,10 +657,35 @@ class Parser:
 
         order = self._parse_order(None)
 
+        spec = None
+        kind = self._match(TokenType.ROWS, TokenType.RANGE)
+
+        if kind:
+            self._match(TokenType.BETWEEN)
+            start = self._parse_window_spec()
+            self._match(TokenType.AND)
+            end = self._parse_window_spec()
+
+            spec = exp.WindowSpec(
+                kind=kind,
+                start=start['value'],
+                start_side=start['side'],
+                end=end['value'],
+                end_side=end['side'],
+            )
+
         if not self._match(TokenType.R_PAREN):
             self.raise_error('Expecting )')
 
-        return exp.Window(this=this, partition=partition, order=order)
+        return exp.Window(this=this, partition=partition, order=order, spec=spec)
+
+    def _parse_window_spec(self):
+        self._match(TokenType.BETWEEN)
+
+        return {
+            'value': self._match(TokenType.UNBOUNDED, TokenType.CURRENT_ROW) or self._parse_primary(),
+            'side': self._match(TokenType.PRECEDING, TokenType.FOLLOWING),
+        }
 
     def _parse_alias(self, this):
         self._match(TokenType.ALIAS)
@@ -675,8 +697,13 @@ class Parser:
         return this
 
     def _parse_id_var(self):
-        if self._match(TokenType.IDENTIFIER, TokenType.VAR):
-            return self._prev
+        return self._match(TokenType.IDENTIFIER, TokenType.VAR)
+
+    def _parse_interval(self):
+        if self._match(TokenType.INTERVAL):
+            this = self._match(TokenType.STRING, TokenType.NUMBER)
+            unit = self._match(TokenType.VAR)
+            return exp.Interval(this=this, unit=unit)
         return None
 
     def _parse_csv(self, parse):
@@ -699,11 +726,11 @@ class Parser:
 
     def _match(self, *types):
         if not self._curr:
-            return False
+            return None
 
         for token_type in types:
             if self._curr.token_type == token_type:
                 self._advance()
-                return True
+                return self._prev
 
-        return False
+        return None
